@@ -1,11 +1,11 @@
-from ctypes import Union
-from functools import partial
+import glob
 import importlib
+import json
+import os.path as osp
 import re
 import sys
-import json
-import glob
-import os.path as osp
+from copy import deepcopy
+from functools import partial
 from typing import Any, Dict
 
 _CFGOPT_PROTOCOL = "cfg://"
@@ -94,6 +94,9 @@ class CfgOptParseResult:
     
     def __getattr__(self, attrname):
         return getattr(self.data, attrname)
+    
+    def __call__(self, *args: Any, **kwds: Any) -> Any:
+        return self["__class__"](*args, **kwds)
 
 
 def parse_configs(cfg_root:str) -> CfgOptParseResult:
@@ -120,7 +123,7 @@ def parse_configs(cfg_root:str) -> CfgOptParseResult:
     router = CfgOptParseResult(root)
 
     # use command line options to update json configs
-    updator_pattern = re.compile("^--(.*)=(.*)")
+    updator_pattern = re.compile("^--(.*\.json.*)=(.*)")
     for updator in sys.argv:
         match_obj = updator_pattern.fullmatch(updator)
         if match_obj:
@@ -136,17 +139,21 @@ def parse_configs(cfg_root:str) -> CfgOptParseResult:
             router[uri] = data
 
     # parse block reference
-    def parse_json_block_reference(data):
+    def parse_json_block_reference(data, uri):
         if isinstance(data, dict):
             for k in data:
-                data[k] = parse_json_block_reference(data[k])
+                data[k] = parse_json_block_reference(data[k], f"{uri}/{k}")
         elif isinstance(data, list):
-            data = [parse_json_block_reference(_) for _ in data]
+            data = [parse_json_block_reference(d, f"{uri}/{i}") for i, d in enumerate(data)]
         elif isinstance(data, str) and data.startswith(_CFGOPT_PROTOCOL):
-            data = router[data].data
+            if ".json" not in data:  # will be interpret as a relative uri
+                data = f"{uri}/{data}"
+            data = router[data]
+            if isinstance(data, CfgOptParseResult):
+                data = data.data
         return data
     
-    parse_json_block_reference(root)
+    parse_json_block_reference(root, _CFGOPT_PROTOCOL)
 
     # parse inheritance (2 tasks)
     
@@ -154,7 +161,7 @@ def parse_configs(cfg_root:str) -> CfgOptParseResult:
     def parse_inheritance(data):
         if isinstance(data, dict):
             if "__base__" in data:
-                base:Dict = parse_inheritance(data["__base__"])
+                base:Dict = deepcopy(parse_inheritance(data["__base__"]))
                 data.pop("__base__")
                 base.update(data)
                 data.update(base)
@@ -195,4 +202,4 @@ def parse_configs(cfg_root:str) -> CfgOptParseResult:
     
     parse_python_objects(root)
 
-    return router
\ No newline at end of file
+    return router
